
GT GENERATOR APP
Preparing OCR, SR Ground Truth from extracted images

Dependencies
-------------
python 3

sudo apt-get install python3-tk

sudo apt-get install python3-pil python3-pil.imagetk
sudo apt-get install python3-tk
pip3 install python-Levenshtein
